summaryrefslogtreecommitdiffstats
path: root/nuttx/configs/cloudctrl/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/cloudctrl/src/up_buttons.c')
-rw-r--r--nuttx/configs/cloudctrl/src/up_buttons.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/configs/cloudctrl/src/up_buttons.c b/nuttx/configs/cloudctrl/src/up_buttons.c
index 06aa884455..18e4d9057a 100644
--- a/nuttx/configs/cloudctrl/src/up_buttons.c
+++ b/nuttx/configs/cloudctrl/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be
@@ -147,7 +147,7 @@ uint8_t board_buttons(void)
* BUTTON_*_BIT and JOYSTICK_*_BIT definitions in board.h for the meaning
* of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See
* the
@@ -158,7 +158,7 @@ uint8_t board_buttons(void)
****************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources.
* After that, board_buttons() may be called to collect the current state of
- * all buttons or up_irqbutton() may be called to register button interrupt
+ * all buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -147,7 +147,7 @@ uint8_t board_buttons(void)
* of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See